@@ -5,13 +5,16 @@ from rich.console import Console
 from rich.logging import RichHandler
 from rich.theme import Theme
 
-custom_theme = Theme({"info": "cyan", "warning": "purple4", "danger": "bold red"})
+custom_theme = Theme(
+    {"info": "cyan", "warning": "purple4", "danger": "bold red"}
+)
 console = Console(
     log_time=False,
     log_path=False,
     theme=custom_theme,
-    width=280,
-    color_system="auto",
+    color_system="256",
+    force_terminal=True,
+    highlight=True,
     record=True,
 )
 
@@ -21,7 +24,10 @@ logging.basicConfig(
     datefmt="[%X]",
     handlers=[
         RichHandler(
-            console=console, markup=True, show_path=False, enable_link_path=False
+            console=console,
+            markup=True,
+            show_path=False,
+            enable_link_path=False,
         )
     ],
 )
@@ -32,3 +38,7 @@ if os.getenv("SCAN_DEBUG_MODE") == "debug":
     LOG.setLevel(logging.DEBUG)
 
 DEBUG = logging.DEBUG
+
+for log_name, log_obj in logging.Logger.manager.loggerDict.items():
+    if not log_name.startswith("blint") and not log_name.startswith("depscan"):
+        log_obj.disabled = True
